==> irp-sdk-1.1.11-sources.jar: org/bdware/irp3/codec/predefined/ServerRecord.java <==
package org.bdware.irp3.codec.predefined;

import io.netty.buffer.ByteBuf;
import org.bdware.irp3.codec.ByteList;

public class ServerRecord {
    int serverID;
    byte[] address;
    byte[] publicKeyRecord;
    ServiceInterface[] serviceInterfaces;

    //publicKey=  keytype(string), 2byte reserved,
    public static ServerRecord fromByteBuf(ByteBuf byteBuf) {
        ServerRecord record = new ServerRecord();
        record.serverID = byteBuf.readInt();
        record.address = ByteList.fromByteBuf(byteBuf);
        record.publicKeyRecord = ByteList.fromByteBuf(byteBuf);
        record.serviceInterfaces = ServiceInterface.listFromByteBuf(byteBuf);
        return record;
    }

    public static ServerRecord[] listFromByteBuf(ByteBuf byteBuf) {
        int len = byteBuf.readInt();
        if (len <= 0) len = 0;
        ServerRecord[] ret = new ServerRecord[len];
        for (int i = 0; i < len; i++)
            ret[i] = fromByteBuf(byteBuf);
        return ret;
    }

    public void toByteBuf(ByteBuf byteBuf) {
        byteBuf.writeInt(serverID);
        ByteList.toByteBuf(address, byteBuf);
        ByteList.toByteBuf(publicKeyRecord, byteBuf);
        ServiceInterface.toByteBuf(serviceInterfaces, byteBuf);
    }

    public static void toByteBuf(ServerRecord[] serverRecords, ByteBuf byteBuf) {
        if (serverRecords == null || serverRecords.length == 0) {
            byteBuf.writeInt(0);
            return;
        }
        byteBuf.writeInt(serverRecords.length);
        for (int i = 0; i < serverRecords.length; i++)
            serverRecords[i].toByteBuf(byteBuf);
        return;
    }
}

==> irp-sdk-1.1.13-sources.jar: org/bdware/irp3/codec/predefined/ServerRecord.java <==
package org.bdware.irp3.codec.predefined;

import io.netty.buffer.ByteBuf;
import org.bdware.irp3.codec.ByteList;

public class ServerRecord {
    int serverID;
    byte[] address; // Fixed 16-byte IPv6 address
    byte[] publicKeyRecord;
    ServiceInterface[] serviceInterfaces;

    //publicKey=  keytype(string), 2byte reserved,
    public static ServerRecord fromByteBuf(ByteBuf byteBuf) {
        ServerRecord record = new ServerRecord();
        record.serverID = byteBuf.readInt();
        record.address = new byte[16];
        byteBuf.readBytes(record.address);
        record.publicKeyRecord = ByteList.fromByteBuf(byteBuf);
        record.serviceInterfaces = ServiceInterface.listFromByteBuf(byteBuf);
        return record;
    }

    public static ServerRecord[] listFromByteBuf(ByteBuf byteBuf) {
        int len = byteBuf.readInt();
        if (len <= 0) len = 0;
        ServerRecord[] ret = new ServerRecord[len];
        for (int i = 0; i < len; i++)
            ret[i] = fromByteBuf(byteBuf);
        return ret;
    }

    public void toByteBuf(ByteBuf byteBuf) {
        byteBuf.writeInt(serverID);
        // Write fixed 16-byte IPv6 address without length prefix
        if (address == null || address.length != 16) {
            throw new IllegalStateException("Address must be exactly 16 bytes for IPv6");
        }
        byteBuf.writeBytes(address);
        ByteList.toByteBuf(publicKeyRecord, byteBuf);
        ServiceInterface.toByteBuf(serviceInterfaces, byteBuf);
    }

    public static void toByteBuf(ServerRecord[] serverRecords, ByteBuf byteBuf) {
        if (serverRecords == null || serverRecords.length == 0) {
            byteBuf.writeInt(0);
            return;
        }
        byteBuf.writeInt(serverRecords.length);
        for (int i = 0; i < serverRecords.length; i++)
            serverRecords[i].toByteBuf(byteBuf);
        return;
    }
}
